@@ -12,16 +12,8 @@ from lxml import etree
 
 import myokit
 import myokit.formats
-import myokit.mxml
 
-
-info = """
-Creates a myokit.Model definition from a CellML file.
-
-CellML versions 1.0, 1.1, and 2.0 are supported, though with some limitations
-(for full support information, see myokit.formats.cellml.v1.api.Model and
-myokit.formats.cellml.v2.api.Model).
-""".strip()
+from myokit.formats.xml import split
 
 
 class CellMLImporterError(myokit.ImportError):
@@ -32,18 +24,12 @@ class CellMLImporterError(myokit.ImportError):
 
 class CellMLImporter(myokit.formats.Importer):
     """
-    This:class:`Importer <myokit.formats.Importer>` imports a model definition
+    This :class:`Importer <myokit.formats.Importer>` imports a model definition
     from CellML.
     """
     def __init__(self, verbose=False):
         super(CellMLImporter, self).__init__()
 
-    def info(self):
-        """
-        Returns a string containing information about this importer.
-        """
-        return info
-
     def model(self, path):
         """
         Reads a CellML file and returns a:class:`myokit.Model`.
@@ -57,12 +43,6 @@ class CellMLImporter(myokit.formats.Importer):
             cellml.NS_CELLML_2_0: v2.CellMLParser,
         }
 
-        # Clear logger and warnings
-        log = self.logger()
-        log.clear()
-        log.clear_warnings()
-        log.log('Importing ' + str(path))
-
         # Open XML file
         try:
             parser = etree.XMLParser(remove_comments=True)
@@ -74,7 +54,7 @@ class CellMLImporter(myokit.formats.Importer):
         root = tree.getroot()
 
         # Detect namespace, create appropriate parser
-        ns, el = myokit.mxml.split(root.tag)
+        ns, el = split(root.tag)
         try:
             parser = parsers[ns]
         except KeyError:
@@ -84,16 +64,9 @@ class CellMLImporter(myokit.formats.Importer):
         parser = parser()
 
         try:
-            # Parse CellML model
+            # Parse and validate CellML model
             cellml_model = parser.parse(root)
-
-            # Log warnings, if any
-            warnings = cellml_model.validate()
-            for warning in warnings:
-                log.warn(warning)
-
-            # Log result
-            log.log('Import successful.')
+            cellml_model.validate()
 
             # Create and return Myokit model
             return cellml_model.myokit_model()
